@@ -35,11 +35,11 @@ extern "C" {
  *
  * Library version string
  */
-#define LIBFDISK_VERSION   "2.33.2"
+#define LIBFDISK_VERSION   "2.35.0"
 
 #define LIBFDISK_MAJOR_VERSION   2
-#define LIBFDISK_MINOR_VERSION   33
-#define LIBFDISK_PATCH_VERSION   2
+#define LIBFDISK_MINOR_VERSION   35
+#define LIBFDISK_PATCH_VERSION   0
 
 /**
  * fdisk_context:
@@ -144,7 +144,7 @@ struct fdisk_labelitem;
  * @FDISK_ASKTYPE_OFFSET:  ask for offset
  * @FDISK_ASKTYPE_WARN:  print warning message and errno
  * @FDISK_ASKTYPE_WARNX: print warning message
- * @FDISK_ASKTYPE_INFO: print infor message
+ * @FDISK_ASKTYPE_INFO: print info message
  * @FDISK_ASKTYPE_YESNO: ask Yes/No question
  * @FDISK_ASKTYPE_STRING: ask for string
  * @FDISK_ASKTYPE_MENU: ask for menu item
@@ -195,6 +195,8 @@ int fdisk_is_labeltype(struct fdisk_context *cxt, enum fdisk_labeltype id);
 
 int fdisk_assign_device(struct fdisk_context *cxt,
 			const char *fname, int readonly);
+int fdisk_assign_device_by_fd(struct fdisk_context *cxt, int fd,
+                        const char *fname, int readonly);
 int fdisk_deassign_device(struct fdisk_context *cxt, int nosync);
 int fdisk_reassign_device(struct fdisk_context *cxt);
 
@@ -619,7 +621,7 @@ extern int fdisk_bsd_link_partition(struct fdisk_context *cxt);
  * @BSD_LABELITEM_TYPE: type
  * @BSD_LABELITEM_DISK: disk
  * @BSD_LABELITEM_PACKNAME: packname
- * @BSD_LABELITEM_FLAGS: flags (removeable, ecc, badsect)
+ * @BSD_LABELITEM_FLAGS: flags (removable, ecc, badsect)
  * @BSD_LABELITEM_SECSIZE: Bytes/Sector
  * @BSD_LABELITEM_NTRACKS: Tracks/Cylinder
  * @BSD_LABELITEM_SECPERCYL: Sectors/Cylinder
@@ -731,7 +733,7 @@ extern int fdisk_gpt_set_partition_attrs(struct fdisk_context *cxt, size_t partn
  * @GPT_LABELITEM_FIRSTLBA: First Usable LBA
  * @GPT_LABELITEM_LASTLBA: Usable LBA
  * @GPT_LABELITEM_ALTLBA: Alternative LBA (backup header LBA)
- * @GPT_LABELITEM_ENTRIESLBA: Partitions entires array LBA
+ * @GPT_LABELITEM_ENTRIESLBA: Partitions entries array LBA
  * @GPT_LABELITEM_ENTRIESALLOC: Number of allocated entries in entries array
  *
  * GPT specific label items.
@@ -757,6 +759,7 @@ void fdisk_unref_script(struct fdisk_script *dp);
 const char *fdisk_script_get_header(struct fdisk_script *dp, const char *name);
 int fdisk_script_set_header(struct fdisk_script *dp, const char *name, const char *data);
 struct fdisk_table *fdisk_script_get_table(struct fdisk_script *dp);
+int fdisk_script_set_table(struct fdisk_script *dp, struct fdisk_table *tb);
 int fdisk_script_get_nlines(struct fdisk_script *dp);
 int fdisk_script_has_force_label(struct fdisk_script *dp);
 
